import java.rmi.registry.LocateRegistry;
import java.rmi.registry.Registry;


//This client first obtains the stub for the registry by invoking the static LocateRegistry.getRegistry method with the hostname specified on the command line. If no hostname is specified, then null is used as the hostname indicating that the local host address should be used.

//Next, the client invokes the remote method lookup on the registry stub to obtain the stub for the remote object from the server's registry.

//Finally, the client invokes the sayHello method on the remote object's stub, which causes the following actions to happen:

//The client-side runtime opens a connection to the server using the host and port information in the remote object's stub and then serializes the call data.
//The server-side runtime accepts the incoming call, dispatches the call to the remote object, and serializes the result (the reply string "Hello, world!") to the client.
//The client-side runtime receives, deserializes, and returns the result to the caller.
//The response message returned from the remote invocation on the remote object is then printed to System.out.


public class Client {

    private Client() {}

    public static void main(String[] args) {

        String host = (args.length < 1) ? null : args[0];
        try {
            Registry registry = LocateRegistry.getRegistry("localhost", 2001);
            Hello stub = (Hello) registry.lookup("Hello");
		String response=stub.sayHello();
            System.out.println("response: " + response);
		System.out.println("Cube of 10 is:" + stub.cube(10) ); 
		stub.doLoop(5);
        } catch (Exception e) {
            System.err.println("Client exception: " + e.toString());
            e.printStackTrace();
        }
    }
}
